import { GactHistory, Location } from "@gact/history";
import { ReactStore } from "@gact/react-store";
import { PathFor, StoreValue } from "@gact/store";
import { LinkType } from "./createLink";
import { RedirectType } from "./createRedirect";
import { RouteType } from "./createRoute";
import { SwitchType } from "./createSwitch";
import { UsePathParams } from "./createUsePathParams";
import { UseSearchParams } from "./createUseSearchParams";
import { HistoryState } from "./types";
/**
 * Provides declarative routing and navigation.
 *
 * @typeParam S - the Gact store state
 * @typeParam HS - the history state
 */
export declare type Router<HS extends HistoryState = HistoryState> = {
    Redirect: RedirectType<HS>;
    Route: RouteType;
    Switch: SwitchType;
    Link: LinkType<HS>;
    useSearchParams: UseSearchParams;
    usePathParams: UsePathParams;
};
/**
 * Creates a `Router`.
 *
 * @typeParam S - the Gact store state
 * @typeParam HS - the history state
 */
export declare function createRouter<S extends StoreValue, HS extends HistoryState = HistoryState>(store: ReactStore<S>): (locationPath: PathFor<S, Location<HS>>, history: GactHistory<HS>) => Router<HS>;
